@@ -29,8 +29,6 @@
 #include <fcntl.h>
 #include <unistd.h>
 #include <stdlib.h>
-#include <bsd/stdlib.h>
-#include <bsd/sys/tree.h>
 #include <errno.h>
 #include <dirent.h>
 #include <string.h>
@@ -66,6 +64,7 @@
 
 #include "machine.h"
 #include "utils.h"
+#include "tree.h"
 
 #define PROCFS "/proc"
 extern char *myname;
@@ -171,7 +170,7 @@ static char fmt_header[] =
 "    PID X           SIZE   RES STATE   XTIME  QTIME  %CPU LOCKS COMMAND";
 
 char		fmt_header_io[] =
-"    PID    IOPS   IORPS   IOWPS READS WRITES COMMAND";
+"    PID       IOPS      IORPS      IOWPS READS WRITES COMMAND";
 
 /* these are names given to allowed sorting orders -- first is default */
 static char *ordernames[] =
@@ -975,7 +974,7 @@ format_next_io(caddr_t handle)
 	struct top_proc *p = &pgtable[proc_index++];
 
 	snprintf(fmt, sizeof(fmt),
-			"%7d %7.0f %7.0f %7.0f %5s %6s %s",
+			"%7d %10.0f %10.0f %10.0f %5s %6s %s",
 			p->pid,
 			diff_stat(p->iops, p->index) / timediff,
 			diff_stat(p->syscr, p->index) / timediff,
